rdf_parser

Macro rdf_parser 

macro_rules! rdf_parser {
    (
   $(#[$attr:meta])*
   $fn_vis: vis fn $name: ident [$($type_params: tt)*]( $($arg: ident :  $arg_type: ty),*)
     ($input_type: ty) -> $output_type: ty
   where [$($where_clause: tt)*]
     $parser: block
 ) => { ... };
}
Declares a named RDF parser which can be reused.

The expression which creates the parser should have no side effects as it may be called multiple times even during a single parse attempt.

This macro is useful when declaring mutually recursive parsers