pub struct Any;Expand description
A wildcard matcher that matches any RDF component.
Any implements the Matcher trait to enable pattern matching in SPARQL-like
queries where certain positions in a triple pattern can match any value.