pub enum Neigh<S>where
S: NeighsRDF,{
Direct {
p: S::IRI,
o: S::Term,
},
Inverse {
s: S::Subject,
p: S::IRI,
},
}Expand description
Variants
Direct
A direct (outgoing) relationship from the focus node.
Represents a triple pattern: (focusNode, p, o) where the focus node
is the subject, p is the predicate, and o is the object.
Fields
p- The predicate IRI of the relationshipo- The object term that the predicate points to
Inverse
An inverse (incoming) relationship to the focus node.
Represents a triple pattern: (s, p, focusNode) where s is the subject,
p is the predicate, and the focus node is the object.
Fields
s- The subject that has this relationship to the focus nodep- The predicate IRI of the relationship
Implementations
Sourceimpl<S> Neigh<S>where
S: NeighsRDF,
impl<S> Neigh<S>where
S: NeighsRDF,
Sourcepub fn direct(pred: S::IRI, object: S::Term) -> Neigh<S>
pub fn direct(pred: S::IRI, object: S::Term) -> Neigh<S>
Creates a direct (outgoing) neighborhood relationship.
Constructs a neighborhood representing an outgoing arc from a focus node via the specified predicate to the given object.
Arguments
pred- The predicate IRI of the relationshipobject- The object term that the predicate points to
Sourcepub fn inverse(pred: S::IRI, subject: S::Subject) -> Neigh<S>
pub fn inverse(pred: S::IRI, subject: S::Subject) -> Neigh<S>
Creates an inverse (incoming) neighborhood relationship.
Constructs a neighborhood representing an incoming arc to a focus node via the specified predicate from the given subject.
Arguments
pred- The predicate IRI of the relationshipsubject- The subject that has this relationship to the focus node